# useful_prints
**Needs to_precision by :**
- **William Rusnack github.com/BebeSparkelSparkel linkedin.com/in/williamrusnack williamrusnack@gmail.com**
- **Eric Moyer github.com/epmoyer eric@lemoncrab.com**
- **Thomas Hladish https://github.com/tjhladish tjhladish@utexas.edu**
**I am not able to add it to the requirements so please visit [Bitbucket](https://bitbucket.org/william_rusnack/to-precision/src/master/) or [GitHub](https://github.com/BebeSparkelSparkel/to-precision)**

Functions:
- pretty_print_dict
- list_as_fitted_table_string
- pretty_print_list
- pretty_print_sym_double_list
- progress_printer
- main_and_sub_progress_printer


## Links
[GitHub](https://github.com/ICreedenI/useful_prints) | [PyPI](https://pypi.org/project/useful-prints/)